##  Integration Use Case: Application Portfolio Management
Application Portfolio Management is the practice of governing and optimizing inventories of software applications to achieve precise business objectives. This is accomplished by creating transparent overviews of IT application landscapes to standardize software throughout business units, promote agility and innovation, and better evaluate IT costs for development.
By utilizing the integration between Apptio and SAP LeanIX, users can level-up their application portfolio management efforts to:
  * Reduce complexity across the IT landscape with SAP LeanIX as the single source of truth of applications, business capabilities, IT components, organizations, initiatives, and providers
  * Identify gaps in the application portfolio to improve investment decisions
  * Understand how changes within the application portfolio will affect cost pools
  * Increase visibility into historical cost data
